@@ -29,9 +29,6 @@ from django.db import (
     models,
     transaction,
 )
-from django.db.models import (
-    Min,
-)
 
 from m3_gar import (
     config,
@@ -63,7 +60,6 @@ from m3_gar.importer.source.exceptions import (
     TableListLoadingError,
 )
 from m3_gar.models import (
-    Status,
     Version,
 )
 from m3_gar.util import (
@@ -173,15 +169,11 @@ def _load_complete_data(
     ]
 
     if truncate is True:
-        Status.objects.filter(table__in=table_names).delete()
+        Version.objects.update(processed=False)
 
-    if truncate is not False and Status.objects.filter(table__in=table_names).exists():
+    if truncate is not False and Version.objects.filter(processed=True).exists():
         raise DatabaseNotEmptyError()
 
-    for tbl in table_names:
-        st = Status(table=tbl, ver=tablelist.version)
-        st.save()
-
     @async_to_sync
     async def do_the_async_load():
 
@@ -346,6 +338,28 @@ def _load_complete_data(
     uvloop.install()
     do_the_async_load()
 
+    # только если path был равен None - мы имеем право зарегистрировать все версии как обработанные, потому что в этом
+    # случае автоматически разворачивается дамп с последней версии. иначе мы этого точно знать не можем, но попробуем
+    # определить версию из url (если он был передан)
+    if path:
+        error_msg = (
+            'Unknown uploaded version. Please set attribute processed=True to all instances of Version model that less '
+            'or equal to uploaded version yourself, or next update will be more time consuming'
+        )
+        try:
+            URLValidator()(path)
+        except ValidationError:
+            print(error_msg)
+        else:
+            try:
+                url_ver = int(path.split('/')[-2].replace('.', ''))
+                Version.objects.filter(ver__lte=url_ver).update(processed=True)
+            except (IndexError, ValueError):
+                print(error_msg)
+
+    else:
+        Version.objects.update(processed=True)
+
     post_import.send(
         sender=object.__class__,
         version=tablelist.version,
@@ -391,21 +405,17 @@ def update_data(path=None, version=None, limit=1000, tables=None, tempdir=None):
         if tbl not in tablelist.tables:
             continue
 
-        try:
-            st = Status.objects.get(table=tbl)
-        except Status.DoesNotExist:
-            st = Status()
-            st.table = tbl
-        else:
-            if st.ver.ver >= tablelist.version.ver:
-                continue
-
         for table in tablelist.tables[tbl]:
             loader = TableUpdater(limit=limit)
             loader.load(tablelist=tablelist, table=table)
 
-        st.ver = tablelist.version
-        st.save()
+    version.processed = True
+    version.save()
+
+    # удаляем временный файл с архивом обновления
+    temp_file_name = tablelist.wrapper.source.filename
+    if os.path.exists(temp_file_name):
+        os.remove(temp_file_name)
 
 
 def auto_update_data(limit=1000, tables=None, tempdir=None):
@@ -422,13 +432,10 @@ def auto_update_data(limit=1000, tables=None, tempdir=None):
 
     """
 
-    min_version = Status.objects.filter(
-        table__in=get_table_names(None),
-    ).aggregate(Min('ver'))['ver__min']
+    min_ver = Version.objects.filter(processed=True).last()
 
-    if min_version is not None:
-        min_ver = Version.objects.get(ver=min_version)
-        versions = Version.objects.filter(ver__gt=min_version).order_by('ver')
+    if min_ver is not None:
+        versions = Version.objects.filter(ver__gt=min_ver.ver).order_by('ver')
 
         for version in versions:
             pre_update.send(sender=object.__class__, before=min_ver, after=version)
