@@ -47,6 +47,8 @@ class XMLIterator(TableIterator):
                 value = value in ['1', 'true', True]
             elif isinstance(field, models.IntegerField):
                 value = int(value) if value else None
+            else:
+                value = value.strip().replace('\n', '').replace('\r', '')
 
             yield key, value
 
