@@ -28,7 +28,7 @@ from m3_gar.importer.version import (
     fetch_version_info,
 )
 from m3_gar.models import (
-    Status,
+    Version,
 )
 from m3_gar.util import (
     get_table_names_from_models,
@@ -108,7 +108,7 @@ class Command(BaseCommand):
 
         tempdir = self.parse_tempdir_arg(tempdir)
 
-        if (src or remote) and Status.objects.exists() and truncate is None:
+        if (src or remote) and Version.objects.filter(processed=True).exists() and truncate is None:
             self.stderr.write(
                 'One of the tables contains data. '
                 'Truncate all GAR tables manually or use '
