@@ -2,6 +2,9 @@ from django.contrib.postgres.indexes import (
     BTreeIndex,
     HashIndex,
 )
+from django.utils.functional import (
+    cached_property,
+)
 
 from m3_gar.base_models import (
     AddrObj as BaseAddrObj,
@@ -37,15 +40,28 @@ class AddrObjTypes(BaseAddrObjTypes):
     """
     Сведения по типам адресных объектов
     """
+
     class Meta:
         verbose_name = 'Тип адресного объекта'
         verbose_name_plural = 'Типы адресных объектов'
 
+    @property
+    def is_prefix(self):
+        """Признак того, является ли тип объекта префиксом."""
+
+        prefix_short_names = {
+            'г', 'г.', 'г.ф.з.', 'Респ', 'респ.', 'г.о.', 'г', 'г.', 'дп', 'кп', 'п', 'пгт', 'пгт.', 'рп',
+            'автодорога', 'гп', 'д', 'дп.', 'остров', 'с', 'с.',
+        }
+
+        return self.shortname in prefix_short_names
+
 
 class AddrObj(BaseAddrObj, RegionCodeModelMixin):
     """
     Сведения классификатора адресообразующих элементов
     """
+
     class Meta:
         verbose_name = 'Адресообразующий элемент'
         verbose_name_plural = 'Адресообразующие элементы'
@@ -59,6 +75,33 @@ class AddrObj(BaseAddrObj, RegionCodeModelMixin):
             )
         )
 
+    @cached_property
+    def addr_obj_type(self):
+        """Тип адресного объекта."""
+
+        try:
+            result = AddrObjTypes.objects.get(
+                shortname=self.typename,
+                level=self.level,
+            )
+        except AddrObjTypes.DoesNotExist:
+            result = AddrObjTypes()
+
+        return result
+
+    @property
+    def type_full_name(self):
+        """Полное наименование типа."""
+
+        return self.addr_obj_type.name
+
+    @property
+    def is_prefix_type(self):
+        """Признак того, является ли тип объекта префиксом."""
+
+        # 1 - федеральный уровень адресных объектов
+        return self.level != '1' or self.addr_obj_type.is_prefix
+
 
 # На момент описания моделей AddrObjTypes никак не связывается с AddrObj
 # Существующее поле AddrObj.typename - текстовое представление (ул, пер, г, и т.п.)
