@@ -1,3 +1,7 @@
+from django.contrib.postgres.indexes import (
+    HashIndex,
+)
+
 from m3_gar.base_models import (
     Houses as BaseHouses,
     HouseTypes as BaseHouseTypes,
@@ -9,8 +13,8 @@ from m3_gar.models.reestr import (
     ReestrObjects,
 )
 from m3_gar.models.util import (
-    ParamsMixin,
     RegionCodeModelMixin,
+    add_params,
     make_fk,
 )
 
@@ -36,7 +40,7 @@ class AddhouseTypes(BaseHouseTypes):
         verbose_name_plural = 'Типы домов'
 
 
-class Houses(BaseHouses, ParamsMixin, RegionCodeModelMixin):
+class Houses(BaseHouses, RegionCodeModelMixin):
     """
     Сведения по номерам домов улиц городов и населенных пунктов
     """
@@ -47,9 +51,16 @@ class Houses(BaseHouses, ParamsMixin, RegionCodeModelMixin):
         verbose_name = 'Номер дома'
         verbose_name_plural = 'Номера домов'
 
+        indexes = (
+            HashIndex(
+                fields=('objectguid',),
+            ),
+        )
 
 make_fk(Houses, 'housetype', to=HouseTypes, null=True, blank=True)
 make_fk(Houses, 'addtype1', to=AddhouseTypes, null=True, blank=True)
 make_fk(Houses, 'addtype2', to=AddhouseTypes, null=True, blank=True)
 make_fk(Houses, 'opertypeid', to=OperationTypes)
 make_fk(Houses, 'objectid', to=ReestrObjects)
+
+add_params(Houses, 'm3_gar.HousesParams')
